#ifndef JOB_CONNECTTOMIXXX_H
#define JOB_CONNECTTOMIXXX_H

#include "prokyon.h"

#include "jobbase.h"

class Job_ConnectToMixxx : public JobBase  {
public:
    Job_ConnectToMixxx(QString _host, int port);

    int type() {
        return JOB_CONNECT_TO_MIXXX;
    }

    void run();

    ~Job_ConnectToMixxx();

private:
    QString host;
    int port;
};

#endif
